@@ -24,7 +24,6 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-
 #include <libintl.h>
 #include <locale.h>
 #include <glib/gi18n-lib.h>
@@ -286,7 +285,7 @@ rss_home_applet_finalize (GObject *object)
 
 	/* Rama - Free up IPHB resources */
 #if 1
-	close_iphb_handle(iphb_applet_data);
+	close_iphb_handle(&iphb_applet_data);
 	remove_iphb_callback(iphb_applet_data.source_id);
 	iphb_applet_data.source_id = 0;
 	g_free(iphb_applet_data.user_data);
@@ -751,7 +750,7 @@ hw_event_handler(osso_hw_state_t * state, gpointer data)
 gint event_deletion(gpointer data)
 {
 #if 1
-	close_iphb_handle(iphb_applet_data);
+	close_iphb_handle(&iphb_applet_data);
 	remove_iphb_callback(iphb_applet_data.source_id);
 	iphb_applet_data.source_id = 0;
 	//iphb_applet_data.user_data = NULL;
@@ -990,10 +989,13 @@ _applet_dbus_connect(HomeRssApplet * applet,
  *
  * @param applet the applet structure
  * @param timed if the refresh should be timed or not
+ * @param manual_refresh  if the refresh button is clicked 
+ *                    or refresh is automatic. 
+ *                        
  * @return TRUE on success, FALSE on failure
  */
 static gboolean
-_applet_dbus_refresh(HomeRssApplet * applet, gboolean timed)
+_applet_dbus_refresh(HomeRssApplet * applet, gboolean timed, gchar *manual_auto_refresh)
 {
     ULOG_DEBUG(__FUNCTION__);
 
@@ -1025,6 +1027,7 @@ _applet_dbus_refresh(HomeRssApplet * applet, gboolean timed)
             dbus_message_set_auto_start(message, TRUE);
             if (!dbus_message_append_args(message,
                                           DBUS_TYPE_BOOLEAN, &timing,
+					  DBUS_TYPE_STRING,&manual_auto_refresh,
                                           DBUS_TYPE_INVALID))
                 {
                     ULOG_ERR("Could not append args to message");
@@ -1066,19 +1069,20 @@ static gboolean applet_poll_iphb_fd(gpointer data)
 {
 	HomeRssApplet * applet = (HomeRssApplet *)(iphb_applet_data.user_data);
         GConfClient* gconf = gconf_client_get_default();
-        int iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);	
+     //   int iphb_fd = gconf_client_get_int(gconf, RSS_SETTINGS_IPHB_HANDLE_ID, NULL);	commented for 160415.
+         int iphb_fd = get_iphb_fd(iphb_applet_data.iphb_handle);
 	fd_set fds;
 	struct timeval time_wait;
         time_t cur_time = 0;	
 
+	if(0 >= iphb_fd) {
+		return TRUE;
+	}	
+
 	memset(&time_wait, 0, sizeof(struct timeval));
 
 	time_wait.tv_sec = 60;
-	time_wait.tv_usec = 0;
-
-	if(0 >= iphb_fd) {
-		return TRUE;
-	}
+	time_wait.tv_usec = 0;	
 
 	if(1/*CHECK IF DISPLAY IS ON */) {
 		FD_ZERO(&fds);
@@ -1092,7 +1096,7 @@ static gboolean applet_poll_iphb_fd(gpointer data)
 				setup_alarm_event_now(TRUE, &iphb_applet_data);
 				iphb_applet_data.source_id = setup_iphb_callback(&iphb_applet_data);
 				
-				if (_applet_dbus_refresh(applet, FALSE) == FALSE)
+				if (_applet_dbus_refresh(applet, FALSE,"auto") == FALSE)
 				{
 					ULOG_ERR("User requested refresh DBus message failed");
 				}
@@ -2207,7 +2211,7 @@ refresh_button_clicked_cb (GtkWidget *self,
 
     update_refresh_button_image (applet);
 
-    if (_applet_dbus_refresh (applet, FALSE) == FALSE)
+    if (_applet_dbus_refresh (applet, FALSE,"manual") == FALSE)
         {
             ULOG_ERR ("User requested refresh DBus message failed");
         }
